Changelog
==========

0.17.0 - February 15, 2024
============================

* Implemented Jupyter widgets which allow single-click figure download, copy, etc.
* Annotate revisions with the name of the backend, e.g. matplotlib or plotly
* Attach full IPython history to each revision
* Add experimental support for py3Dmol
* Switch API to the new v1.2 endpoint
* Simplify model semantics by removing support for implicit lazy loading
